@@ -1,7 +1,7 @@
 
-# test queries -----------------------------------------------------------------
+# test queries ----
+
 test_that("get_power returns daily point ag data", {
-  skip_on_cran()
   power_query <- get_power(
     community = "ag",
     lonlat = c(-179.5, -89.5),
@@ -47,7 +47,6 @@ test_that("get_power returns daily point ag data", {
       "PS"
     )
   )
-  rm(power_query)
 })
 
 test_that("get_power() returns daily point ag data with adjusted atmospheric
@@ -100,11 +99,9 @@ test_that("get_power() returns daily point ag data with adjusted atmospheric
                 "PS"
               )
             )
-            rm(power_query)
           })
 
 test_that("get_power returns daily point SB data", {
-  skip_on_cran()
   power_query <- get_power(
     community = "sb",
     lonlat = c(-179.5, -89.5),
@@ -130,7 +127,6 @@ test_that("get_power returns daily point SB data", {
   expect_equal(power_query$T2M_MAX, -24.88)
   expect_equal(power_query$RH2M, 94.25)
   expect_equal(power_query$WS10M, 2.32)
-  rm(power_query)
 })
 
 test_that("get_power() returns daily regional ag data", {
@@ -175,7 +171,6 @@ test_that("get_power() returns daily regional ag data", {
   expect_equal(power_query$YYYYMMDD[1], as.Date("1983-01-01"))
   expect_equal(power_query$DOY[1], 1)
   expect_equal(power_query$T2M[1], 3.28)
-  rm(power_query)
 })
 
 test_that("get_power() returns point ag data for climatology", {
@@ -210,9 +205,55 @@ test_that("get_power() returns point ag data for climatology", {
       "ANN"
     )
   )
-  rm(power_query)
 })
 
+# test rate limiting -----
+test_that("get_power() limits requests to 60/minute", {
+  # this code comes from @camwur,
+  # https://github.com/ropensci/nasapower/issues/57, which is how I learned of
+  # the issue and the limits, thanks!
+  skip_on_cran()
+  x <- function(lon, lat) {
+    get_power(
+      community = "ag",
+      lonlat = c(lon, lat),
+      site_elevation = NULL,
+      wind_elevation = NULL,
+      wind_surface = NULL,
+      pars = c("RH2M", "T2M"),
+      temporal_api = "climatology"
+    )
+  }
+  lon <- c(1:2)
+  lat <- c(1:2)
+  y <- purrr::map2(lon, lat, x)
+  expect_length(y, 2)
+})
+
+test_that("get_power() limits requests to 30/minute", {
+  # this code comes from @camwur,
+  # https://github.com/ropensci/nasapower/issues/57, which is how I learned of
+  # the issue and the limits, thanks!
+  skip_on_cran()
+  x <- function(lon, lat) {
+    get_power(
+      community = "ag",
+      lonlat = c(lon, lat),
+      site_elevation = NULL,
+      wind_elevation = NULL,
+      wind_surface = NULL,
+      pars = c("RH2M", "T2M"),
+      dates = c("2015-06-01"),
+      temporal_api = "hourly"
+    )
+  }
+  lon <- c(90:91)
+  lat <- c(0:1)
+  y <- purrr::map2(lon, lat, x)
+  expect_length(y, 2)
+})
+
+# test user input check response messages -----
 test_that("get_power() stops if `temporal_api` not valid", {
   skip_on_cran()
   expect_error(
@@ -285,7 +326,8 @@ test_that("get_power() stops if site_elevation is invalid", {
   )
 })
 
-test_that("get_power() stops wind_surface is supplied w/ no wind_elevation", {
+test_that("get_power() stops wind_surface is supplied w/ no wind_elevation",
+          {
             skip_on_cran()
             expect_error(
               power_query <- get_power(
@@ -329,7 +371,6 @@ test_that("get_power() stops if `global` coverage is requested", {
   )
 })
 
-
 test_that("get_power() stops if temporal_api is hourly and pars > 15", {
   skip_on_cran()
   expect_error(
@@ -361,3 +402,58 @@ test_that("get_power() stops if temporal_api is hourly and pars > 15", {
     regexp = ""
   )
 })
+
+test_that("get_power() gives warning if `temporal_average` is used", {
+  skip_on_cran()
+  expect_warning(
+    power_query <- get_power(
+      community = "ag",
+      lonlat = c(-179.5, -89.5),
+      pars = "T2M",
+      dates = "1983-01-01",
+      temporal_average = "daily"
+    ),
+    regexp = "`temporal_average has been deprecated for `temporal_api`*"
+  )
+})
+
+test_that("get_power() stops if there is no temporal_api()", {
+  skip_on_cran()
+  expect_error(
+    power_query <- get_power(
+      community = "ag",
+      lonlat = c(-179.5, -89.5),
+      pars = "T2M",
+      dates = "1983-01-01"
+    ),
+    regexp = "You must provide a `temporal_api` value."
+  )
+})
+
+test_that("get_power() stops if global lonlat is set", {
+  skip_on_cran()
+  expect_error(
+    power_query <- get_power(
+      community = "ag",
+      lonlat = "global",
+      pars = "T2M",
+      dates = "1983-01-01",
+      temporal_api = "daily"
+    ),
+    regexp = "The POWER team have not enabled `global` data queries with *"
+  )
+})
+
+test_that("get_power() stops if lonlat = is invalid", {
+  skip_on_cran()
+  expect_error(
+    power_query <- get_power(
+      community = "ag",
+      lonlat = "x",
+      pars = "T2M",
+      dates = "1983-01-01",
+      temporal_api = "daily"
+    ),
+    regexp = "You have entered an invalid value for `lonlat`. *"
+  )
+})
